@@ -1,20 +1,17 @@
 from fastapi import FastAPI, Response, Form
 import requests
-from typing import Optional
 import uvicorn
 from .. import api_key, BASE_URL
 
 from ..models.agent import AgentConfig
-from ..models.synthesizer import SynthesizerConfig
 from ..models.telephony import CreateInboundCall
 
-VOCODE_INBOUND_CALL_URL = f"https://api.vocode.dev/create_inbound_call"
+VOCODE_INBOUND_CALL_URL = f"https://{BASE_URL}/create_inbound_call"
 
 class InboundCallServer():
 
-    def __init__(self, agent_config: AgentConfig, synthesizer_config: Optional[SynthesizerConfig]):
+    def __init__(self, agent_config: AgentConfig):
         self.agent_config = agent_config
-        self.synthesizer_config = synthesizer_config
         self.app = FastAPI()
         self.app.post("/vocode")(self.handle_call)
 
@@ -26,14 +23,14 @@ class InboundCallServer():
             },
             json=CreateInboundCall(
                 agent_config=self.agent_config,
-                synthesizer_config=self.synthesizer_config,
                 twilio_sid=twilio_sid
             ).dict()
         )
+        assert response.ok
         return Response(
             response.text,
             media_type="application/xml",
         )
     
     def run(self, host="localhost", port=3000):
-        uvicorn.run(self.app, host=host, port=port)
\ No newline at end of file
+        uvicorn.run(self.app, host=host, port=port, reload=True)
\ No newline at end of file
